Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetConfigPath ¶
GetConfigPath returns the path to the belt configuration file.
Types ¶
type AppConfig ¶
type AppConfig struct {
Name string `koanf:"name"`
Version string `koanf:"version"`
Debug bool `koanf:"debug"`
}
AppConfig holds application-specific settings.
type Config ¶
type Config struct {
App AppConfig `koanf:"app"`
Output OutputConfig `koanf:"output"`
Logging LoggingConfig `koanf:"logging"`
Crypt CryptConfig `koanf:"crypt"`
DNS DNSConfig `koanf:"dns"`
}
Config holds the application configuration.
type CryptConfig ¶
type CryptConfig struct {
Env string `koanf:"env"` // Environment variable name for encryption key
Key string `koanf:"key"` // Base58-encoded encryption key
Warned bool `koanf:"warned"` // Whether user has been warned about key backup
}
CryptConfig holds cryptography settings.
func (*CryptConfig) GetKey ¶
func (c *CryptConfig) GetKey() string
GetKey returns the encryption key, checking environment variable first.
type DNSConfig ¶
type DNSConfig struct {
Server string `koanf:"server"` // Default DNS server
Root bool `koanf:"root"` // Whether to use root servers by default
}
DNSConfig holds DNS settings.
type LoggingConfig ¶
LoggingConfig holds logging settings.
Click to show internal directories.
Click to hide internal directories.