Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Version = GetVersion() Commit = GetCommit() Date = GetBuildDate() )
Variables to store version information
Functions ¶
func CheckVersionFlag ¶
CheckVersionFlag checks if the version flag is present in args and prints version info if it is
func GetBuildDate ¶
func GetBuildDate() string
GetBuildDate returns the current date in ISO 8601 format
func GetVersion ¶
func GetVersion() (version string)
GetVersion attempts to get the version from git tags, falling back to a datetime format or "dev-UNKNOWN" if all else fails
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.